@@ -1,4 +1,4 @@
-/* $Id: irplib_calib.c,v 1.17 2009-02-17 08:05:25 amodigli Exp $
+/* $Id: irplib_calib.c,v 1.19 2013-03-01 10:26:22 llundin Exp $
  *
  * This file is part of the irplib package
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -19,9 +19,9 @@
  */
 
 /*
- * $Author: amodigli $
- * $Date: 2009-02-17 08:05:25 $
- * $Revision: 1.17 $
+ * $Author: llundin $
+ * $Date: 2013-03-01 10:26:22 $
+ * $Revision: 1.19 $
  * $Name: not supported by cvs2svn $
  */
 
@@ -48,6 +48,18 @@ irplib_get_clean_mean_window(cpl_image* img,
                              double* clean_mean, 
                              double* clean_stdev);
 
+/*-----------------------------------------------------------------------------
+                                   Defines
+ -----------------------------------------------------------------------------*/
+
+#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(6, 3, 0)
+#define IRPLIB_FRAMESET_GET       cpl_frameset_get_position
+#else
+/* Remove this branch once CPL versions less than 6.3 are no longer supported */
+#define IRPLIB_FRAMESET_GET       cpl_frameset_get_frame
+#endif
+
+
 static double irplib_pfits_get_dit(const cpl_propertylist * plist);
 static double irplib_pfits_get_exp_time(const cpl_propertylist* plist);
 /*----------------------------------------------------------------------------*/
@@ -114,10 +126,6 @@ irplib_get_clean_mean_window(cpl_image* img,
 
   double mean=0;
   double stdev=0;
-  double threshold=0;
-  double lo_cut=0;
-  double hi_cut=0;
-  cpl_mask* mask=NULL;
   cpl_image* tmp=NULL;
   cpl_stats* stats=NULL;
   int i=0;
@@ -125,7 +133,11 @@ irplib_get_clean_mean_window(cpl_image* img,
   tmp=cpl_image_extract(img,llx,lly,urx,ury);
   cpl_image_accept_all(tmp);
   for(i=0;i<nclip;i++) {
-   
+
+    double threshold=0;
+    double lo_cut=0;
+    double hi_cut=0;
+    cpl_mask* mask=NULL;
 
     cpl_stats_delete(stats);
     stats = cpl_stats_new_from_image(tmp, CPL_STATS_MEAN | CPL_STATS_STDEV);
@@ -186,20 +198,11 @@ irplib_compute_gain(
 
   cpl_frame*    frm=NULL;
 
-  cpl_image* img_on1=NULL;
-  cpl_image* img_on2=NULL;
-  cpl_image* img_on_dif=NULL;
-
-  cpl_image* img_of1=NULL;
-  cpl_image* img_of2=NULL;
-  cpl_image* img_of_dif=NULL;
-
   cpl_table* res_tbl=NULL;
   cpl_vector* dit_on=NULL;
   cpl_vector* dit_of=NULL;
   cpl_vector* exptime_on=NULL;
   cpl_vector* exptime_of=NULL;
-  cpl_propertylist* plist=NULL;
 
   int non=0;
   int nof=0;
@@ -209,25 +212,11 @@ irplib_compute_gain(
   int urx;
   int ury;
 
-  double avg_on1=0;
-  double avg_on2=0;
-  double avg_of1=0;
-  double avg_of2=0;
-  double avg_on_dif=0;
-  double avg_of_dif=0;
-  double std=0;
-
-  double sig_on_dif=0;
-  double sig_of_dif=0;
-  char* name=NULL;
+  const char* name=NULL;
   int i=0;
-  int m=0;
 
-  double gain=0;
   double dit_ref=0;
-  double dit_tmp=0;
   double exptime_ref=0;
-  double exptime_tmp=0;
 
  
   non = cpl_frameset_get_size(son);
@@ -240,9 +229,10 @@ irplib_compute_gain(
   exptime_of=cpl_vector_new(nfr);
 
   for(i=0;i<nfr;i++) {
+    cpl_propertylist* plist=NULL;
 
-    frm=cpl_frameset_get_frame(son,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    frm=IRPLIB_FRAMESET_GET(son,i);
+    name=cpl_frame_get_filename(frm);
     plist=cpl_propertylist_load(name,0);
     dit_ref=irplib_pfits_get_dit(plist);
     exptime_ref=(double)irplib_pfits_get_exp_time(plist);
@@ -250,8 +240,8 @@ irplib_compute_gain(
     cpl_vector_set(dit_on,i,dit_ref);
     cpl_vector_set(exptime_on,i,exptime_ref);
 
-    frm=cpl_frameset_get_frame(sof,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    frm=IRPLIB_FRAMESET_GET(sof,i);
+    name=cpl_frame_get_filename(frm);
     plist=cpl_propertylist_load(name,0);
     dit_ref=irplib_pfits_get_dit(plist);
     exptime_ref=(double)irplib_pfits_get_exp_time(plist);
@@ -274,12 +264,16 @@ irplib_compute_gain(
   cpl_table_new_column(res_tbl,"gain", CPL_TYPE_DOUBLE);
  
   for(i=0;i<nfr;i++) {
-    frm=cpl_frameset_get_frame(son,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    cpl_image* img_on1=NULL;
+    cpl_image* img_of1=NULL;
+    int m=0;
+
+    frm=IRPLIB_FRAMESET_GET(son,i);
+    name=cpl_frame_get_filename(frm);
     img_on1=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
 
-    frm=cpl_frameset_get_frame(sof,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    frm=IRPLIB_FRAMESET_GET(sof,i);
+    name=cpl_frame_get_filename(frm);
     img_of1=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
 
 
@@ -289,14 +283,34 @@ irplib_compute_gain(
    
     for(m=0;m<nfr; m++) {
       if(m != i) {
-	frm=cpl_frameset_get_frame(son,m);
-	name=(char*)cpl_frame_get_filename(frm);
+        double dit_tmp=0;
+        double exptime_tmp=0;
+
+	frm=IRPLIB_FRAMESET_GET(son,m);
+	name=cpl_frame_get_filename(frm);
 	dit_tmp=cpl_vector_get(dit_on,m);
 	exptime_tmp=cpl_vector_get(exptime_on,m);
 	if(dit_tmp == dit_ref && exptime_tmp == exptime_ref) {
+          cpl_image* img_on2=NULL;
+          cpl_image* img_on_dif=NULL;
+
+          cpl_image* img_of2=NULL;
+          cpl_image* img_of_dif=NULL;
+
+          double avg_on1=0;
+          double avg_on2=0;
+          double avg_of1=0;
+          double avg_of2=0;
+          double avg_on_dif=0;
+          double avg_of_dif=0;
+          double std=0;
+          double sig_on_dif=0;
+          double sig_of_dif=0;
+          double gain=0;
+
 	  img_on2=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
-	  frm=cpl_frameset_get_frame(sof,m);
-	  name=(char*)cpl_frame_get_filename(frm);
+	  frm=IRPLIB_FRAMESET_GET(sof,m);
+	  name=cpl_frame_get_filename(frm);
 	  img_of2=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
 
 	  img_on_dif=cpl_image_subtract_create(img_on1,img_on2);
@@ -360,33 +374,19 @@ irplib_compute_gain(
 cpl_table* irplib_compute_linearity(cpl_frameset* son, cpl_frameset* sof)
 {
 
-
-  cpl_frame*    frm=NULL;
-
-  int* status=0;
   int non=0;
   int nof=0;
   int nfr=0;
   int i=0;
-  double med_on=0;
-  double avg_on=0;
-  double med_of=0;
-  double avg_of=0;
   double med_dit=0;
-  double avg_dit=0;
+  /*double avg_dit=0;*/
 
-  double med=0;
-  double avg=0;
-
-  char* name=NULL;
-  cpl_image* img=NULL;
   cpl_vector* vec_adl=NULL;
   cpl_vector* vec_dit=NULL;
   cpl_vector* vec_avg=NULL;
   cpl_vector* vec_med=NULL;
   cpl_vector* vec_avg_dit=NULL;
   cpl_vector* vec_med_dit=NULL;
-  cpl_propertylist* plist=NULL;
 
   double dit=0;
   cpl_table* lin_tbl=NULL;
@@ -409,15 +409,30 @@ cpl_table* irplib_compute_linearity(cpl_frameset* son, cpl_frameset* sof)
   vec_dit=cpl_vector_new(nfr);
   vec_adl=cpl_vector_new(nfr);
   for(i=0;i<nfr;i++) {
-    frm=cpl_frameset_get_frame(son,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    cpl_frame*    frm=NULL;
+
+    double med_on=0;
+    double avg_on=0;
+    double med_of=0;
+    double avg_of=0;
+
+    double med=0;
+    double avg=0;
+    double avg_dit=0;
+
+    const char* name=NULL;
+    cpl_image* img=NULL;
+    cpl_propertylist* plist=NULL;
+
+    frm=IRPLIB_FRAMESET_GET(son,i);
+    name=cpl_frame_get_filename(frm);
     img=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
     med_on=cpl_image_get_median(img);
     avg_on=cpl_image_get_mean(img);
     cpl_image_delete(img);
 
-    frm=cpl_frameset_get_frame(sof,i);
-    name=(char*)cpl_frame_get_filename(frm);
+    frm=IRPLIB_FRAMESET_GET(sof,i);
+    name=cpl_frame_get_filename(frm);
     img=cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
     med_of=cpl_image_get_median(img);
     avg_of=cpl_image_get_mean(img);
@@ -446,9 +461,10 @@ cpl_table* irplib_compute_linearity(cpl_frameset* son, cpl_frameset* sof)
   }
   cpl_table_new_column(lin_tbl,"adl", CPL_TYPE_DOUBLE);
   med_dit=cpl_vector_get_mean(vec_med_dit);
-  avg_dit=cpl_vector_get_mean(vec_avg_dit);
+  /*avg_dit=cpl_vector_get_mean(vec_avg_dit);*/
 
   for(i=0;i<nfr;i++) {
+    int* status=0;
     dit = cpl_table_get_double(lin_tbl,"dit",i,status);
     cpl_vector_set(vec_adl,i,dit*med_dit);
     cpl_table_set_double(lin_tbl,"adl",i,dit*med_dit);
@@ -569,17 +585,12 @@ int irplib_flat_dark_bpm_calib(
         const char          *   dark,
         const char          *   bpm)
 {
-    cpl_image       *   dark_image ;
-    cpl_image       *   flat_image ;
-    cpl_mask        *   bpm_im_bin ;
-    cpl_image       *   bpm_im_int ;
-    int                 i ;
-
     /* Test entries */
     if (ilist == NULL) return -1 ;
 
     /* Dark correction */
     if (dark != NULL) {
+        cpl_image       *   dark_image ;
         cpl_msg_info(cpl_func, "Subtract the dark to the images") ;
         /* Load the dark image */
         if ((dark_image = cpl_image_load(dark, CPL_TYPE_FLOAT, 0, 0)) == NULL) {
@@ -597,6 +608,7 @@ int irplib_flat_dark_bpm_calib(
 
     /* Flat-field correction */
     if (flat != NULL) {
+        cpl_image       *   flat_image ;
         cpl_msg_info(cpl_func, "Divide the images by the flatfield") ;
         /* Load the flat image */
         if ((flat_image = cpl_image_load(flat, CPL_TYPE_FLOAT, 0, 0)) == NULL) {
@@ -614,6 +626,9 @@ int irplib_flat_dark_bpm_calib(
 
     /* Correct the bad pixels if requested */
     if (bpm != NULL) {
+        cpl_mask        *   bpm_im_bin ;
+        cpl_image       *   bpm_im_int ;
+        int                 i ;
         cpl_msg_info(cpl_func, "Correct the bad pixels in the images") ;
          /* Load the bad pixels image */
         if ((bpm_im_int = cpl_image_load(bpm, CPL_TYPE_INT, 0, 0)) == NULL) {
