@@ -30,6 +30,10 @@
 #define _XOPEN_SOURCE 600 /* setenv */
 #endif
 
+#ifndef ESO_COVERAGE_BUILD
+#define ESO_COVERAGE_BUILD 0
+#endif
+
 #include "visir_recipe.h"
 
 #include "visir_utils.h"
@@ -106,7 +110,7 @@ static int visir_img_reduce_exec(cpl_plugin * plugin)
         setenv("OMP_NUM_THREADS", "0", 1);
         return visir_tmpdir_exec(RECIPE_STRING, plugin, visir_img_reduce);
     }
-    else if (getenv("VISIR_NO_FORK") != NULL) {
+    else if (ESO_COVERAGE_BUILD || getenv("VISIR_NO_FORK") != NULL) {
         /* debugging and coverage is better without fork */
         return cpl_recipedefine_exec(plugin, visir_img_reduce)
             ? (int)cpl_error_set_where(cpl_func) : 0;
