@@ -1,4 +1,4 @@
-/* $Id: visir_img_combine.c,v 1.107 2010/10/21 11:51:32 llundin Exp $
+/* $Id: visir_img_combine.c,v 1.107 2010-10-21 11:51:32 llundin Exp $
  *
  * This file is part of the VISIR Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2010/10/21 11:51:32 $
+ * $Date: 2010-10-21 11:51:32 $
  * $Revision: 1.107 $
- * $Name: visir-3_5_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,7 +39,7 @@
                                 Defines
  -----------------------------------------------------------------------------*/
 
-#define RECIPE_STRING   "visir_img_combine"
+#define RECIPE_STRING   "visir_old_img_combine"
 
 /* FITS keys to be loaded for all raw files */
 #define RECIPE_KEYS_REGEXP_ALL \
@@ -78,7 +78,7 @@ static cpl_error_code visir_img_combine_save(cpl_frameset *,
                                              const char      *,
                                              const char      *);
 
-VISIR_RECIPE_DEFINE(visir_img_combine,
+VISIR_RECIPE_DEFINE(visir_old_img_combine,
                     VISIR_PARAM_REFINE | VISIR_PARAM_XCORR |    
                     VISIR_PARAM_OFFSETS | VISIR_PARAM_OBJECTS | 
                     VISIR_PARAM_NODPOS |  VISIR_PARAM_AUTOBPM | 
@@ -87,7 +87,7 @@ VISIR_RECIPE_DEFINE(visir_img_combine,
                     VISIR_PARAM_COMBINE | VISIR_PARAM_ECCMAX |
                     VISIR_PARAM_STRIPITE | VISIR_PARAM_STRIPMOR |
                     VISIR_PARAM_PLOT,
-                    "Images combination recipe",
+                    "Old DRS detector: Images combination recipe",
                     "This recipe recombines the data observed in "
                     "chopping/nodding or\n"
                     "chopping or nodding modes into one combined image using "
@@ -134,7 +134,7 @@ VISIR_RECIPE_DEFINE(visir_img_combine,
   @return   0 iff everything is ok
  */
 /*----------------------------------------------------------------------------*/
-static int visir_img_combine(cpl_frameset            * framelist,
+static int visir_old_img_combine(cpl_frameset            * framelist,
                              const cpl_parameterlist * parlist)
 {
     cpl_errorstate  cleanstate = cpl_errorstate_get();
