@@ -223,6 +223,9 @@ propagate_qc_header(cpl_propertylist * qclist, const cpl_propertylist * ppqc)
     s = cpl_propertylist_get_string(ppqc, "BUNIT");
     cpl_propertylist_append_string(qclist, "BUNIT", s);
 
+    s = cpl_propertylist_get_string(ppqc, "ESO DRS CATG");
+    cpl_propertylist_append_string(qclist, "ESO DRS CATG", s);
+
     d = cpl_propertylist_get_double(ppqc, "ESO QC BACKGD MEAN");
     cpl_propertylist_append_double(qclist, "ESO QC BACKGD MEAN", d);
 
@@ -369,7 +372,7 @@ static int visir_old_img_phot(cpl_frameset            * framelist,
         if (rawframes == NULL) {
             cpl_errorstate_set(cleanstate);
             rawframes = irplib_framelist_extract(allframes,
-                                                 "IM_CAL_PHOT_PREPROCESSED");
+                                                 VISIR_IMG_CAL_PHOT_PP);
             skip_if (rawframes == NULL);
             const char * fn =
                 irplib_frameset_find_file(framelist, VISIR_UTIL_QC_PROCATG);
@@ -489,7 +492,7 @@ static int visir_old_img_phot(cpl_frameset            * framelist,
     cpl_msg_info(cpl_func, "Combining the images");
     {
         const char * pre =
-            irplib_frameset_find_file(framelist, "IM_CAL_PHOT_PREPROCESSED");
+            irplib_frameset_find_file(framelist, VISIR_IMG_CAL_PHOT_PP);
         if (pre) {
             combined = cpl_calloc(2, sizeof(combined[0]));
             combined[0] = cpl_image_load(pre, CPL_TYPE_UNSPECIFIED, 0, 0);
@@ -1265,8 +1268,10 @@ static int visir_img_phot_flux_one(const cpl_image * combined,
          * only the int cast is used later, so pixel precision of
          * maxpos is ok */
         cpl_size yp, xp;
-        cpl_image_get_maxpos_window(combined, x - 5, y - 5,
-                                    x + 5, y + 5, &xp, &yp);
+        cpl_image_get_maxpos_window(combined,
+                    CX_MAX(1, x - 5), CX_MAX(1, y - 5),
+                    CX_MIN(cpl_image_get_size_x(combined), x + 5),
+                    CX_MIN(cpl_image_get_size_y(combined), y + 5), &xp, &yp);
         x = xp;
         y = yp;
     }
@@ -2124,6 +2129,10 @@ static cpl_error_code visir_get_filter_infos(
     else if (!strcmp(f, "Q4"))     { cwlen = 20.5;dwlen = 1.0;}
     else if (!strcmp(f, "Q7"))     { cwlen = 23.1;dwlen = 0.8;}
     else if (!strcmp(f, "Q8"))     { cwlen = 24.5;dwlen = 0.8;}
+    /* TODO missing bandwidth for coro filters not determined yet */
+    else if (!strcmp(f, "10_5_4QP"))     { cwlen = 10.5;dwlen =0.1;}
+    else if (!strcmp(f, "11_3_4QP"))     { cwlen = 11.3;dwlen =0.1;}
+    else if (!strcmp(f, "12_4_AGP"))     { cwlen = 12.4;dwlen =0.1;}
     else if (!strcmp(f, "N-SW-spec") || !strcmp(f, "N_SW_spec"))
         { cwlen = 8.85; dwlen = 2.7;}
     else if (!strcmp(f, "H2S4-spec") || !strcmp(f, "H2S4_spec"))
