@@ -96,7 +96,7 @@ visir_util_apply_calib_fill_parameterlist(cpl_parameterlist * self)
 }
 
 
-static cpl_error_code
+static cpl_frameset *
 get_img_conv(double * conv, double * error,
              irplib_framelist * phot_frames)
 {
@@ -105,9 +105,10 @@ get_img_conv(double * conv, double * error,
     cpl_errorstate cleanstate = cpl_errorstate_get();
     irplib_framelist * one_frames =  NULL;
     irplib_framelist * cmb_frames =  NULL;
+    cpl_frameset * usedframes = cpl_frameset_new();
     cpl_propertylist * cmb_plist;
 
-    cpl_ensure_code(conv, CPL_ERROR_NULL_INPUT);
+    cpl_ensure(conv, CPL_ERROR_NULL_INPUT, NULL);
 
     skip_if(irplib_framelist_load_propertylist_all(phot_frames, 0,
                                                    "ESO QC", 0));
@@ -118,12 +119,15 @@ get_img_conv(double * conv, double * error,
     skip_if(irplib_framelist_contains(cmb_frames, "ESO QC CONVER",
                                       CPL_TYPE_DOUBLE, CPL_FALSE, 0.));
     cmb_plist = irplib_framelist_get_propertylist(cmb_frames, 0);
+    cpl_frameset_insert(usedframes,
+                  cpl_frame_duplicate(irplib_framelist_get(cmb_frames, 0)));
 
     one_frames = irplib_framelist_extract(phot_frames,
                                           VISIR_IMG_PHOT_ONEBEAM_PROCATG);
     if (one_frames == NULL)
         cpl_errorstate_set(cleanstate);
     else {
+        /* TODO unused */
         skip_if(irplib_framelist_contains(one_frames, "ESO QC CONVER",
                                           CPL_TYPE_DOUBLE, CPL_FALSE, 0.));
 
@@ -154,8 +158,11 @@ get_img_conv(double * conv, double * error,
     cpl_vector_delete(v);
     irplib_framelist_delete(cmb_frames);
     irplib_framelist_delete(one_frames);
+    if (cpl_error_get_code()) {
+        cpl_frameset_delete(usedframes);
+    }
 
-    return cpl_error_get_code();
+    return usedframes;
 }
 
 static cpl_error_code
@@ -268,7 +275,8 @@ planelist_from_frame(const cpl_frame * frame)
 static cpl_error_code
 apply_img_calib(cpl_frameset *framelist, const cpl_parameterlist * parlist,
                 irplib_framelist * objects,
-                const double conv, const double error)
+                const double conv, const double error,
+                cpl_frameset * calibframes)
 {
     cpl_frameset * usedframes = cpl_frameset_new();
     cx_list * planes = NULL;
@@ -283,7 +291,12 @@ apply_img_calib(cpl_frameset *framelist, const cpl_parameterlist * parlist,
         skip_if(planes == NULL);
 
         cpl_frame_set_group(frm, CPL_FRAME_GROUP_RAW);
+
         cpl_frameset_insert(usedframes, cpl_frame_duplicate(frm));
+        FOR_EACH_FRAMESET(cfrm, calibframes) {
+            cpl_frame_set_group(cfrm, CPL_FRAME_GROUP_RAW);
+            cpl_frameset_insert(usedframes, cpl_frame_duplicate(cfrm));
+        }
         skip_if(0);
 
         visir_plane * first = cx_list_front(planes);
@@ -295,7 +308,7 @@ apply_img_calib(cpl_frameset *framelist, const cpl_parameterlist * parlist,
         sprintf(buffer, "visir_calibrated_%03d.fits", i + 1);
         irplib_dfs_save_image(framelist, parlist, usedframes, simg,
                               CPL_TYPE_FLOAT, RECIPE_STRING,
-                              cpl_frame_get_tag(frm), first->plist,
+                              VISIR_IMG_OBJ_CALIBRATED_PROCATG, first->plist,
                               NULL, visir_pipe_id, buffer);
         cpl_image_delete(simg);
         skip_if(0);
@@ -620,8 +633,9 @@ static int visir_util_apply_calib(cpl_frameset            * framelist,
         irplib_framelist_get_size(allframes)) {
         double conv = 1., error = 0.;
         cpl_msg_info(cpl_func, "Applying conversion factor");
-        skip_if(get_img_conv(&conv, &error, allframes));
-        skip_if(apply_img_calib(framelist, parlist, objects, conv, error));
+        cpl_frameset * calibframes = get_img_conv(&conv, &error, allframes);
+        skip_if(calibframes == NULL);
+        skip_if(apply_img_calib(framelist, parlist, objects, conv, error, calibframes));
         others = irplib_framelist_extract_regexp(allframes, ".*OBJ.*", CPL_TRUE);
         skip_if(propagate_all(framelist, parlist, others));
     }
