@@ -347,7 +347,7 @@ visir_util_detect_shift_fill_parameterlist(cpl_parameterlist * self)
 
     err =
         irplib_parameterlist_set_double(self, PACKAGE, RECIPE_STRING, "eccmax",
-                                      0.25, NULL, context,
+                                      3.0, NULL, context,
                        "The maximum eccentricity allowed in the combination "
                        "of the three (in parallel nod/chopping) or four (in "
                        "perpendicular nod/chopping) beams. In parallel mode, "
@@ -1266,7 +1266,8 @@ cpl_error_code visir_util_detect_shift_one(cpl_frameset * framelist,
         double dxb = cpl_propertylist_get_double(mplist, VISIR_DRS_CUMOFFSETXB);
         double dyb = cpl_propertylist_get_double(mplist, VISIR_DRS_CUMOFFSETYB);
         FOR_EACH_T(beam_info * bi, beampos) {
-            if (bi->type == VISIR_PLANE_AOFF || bi->type == VISIR_PLANE_AON) {
+            if (bi->type == VISIR_PLANE_AOFF || bi->type == VISIR_PLANE_AON ||
+                bi->type == VISIR_PLANE_UNDEFINED) {
                 bi->x += dxa;
                 bi->y += dya;
             }
