@@ -203,7 +203,7 @@ class DataPlotterManager:
             self.dlg.figure.clf()
         ax = self.dlg.figure.add_subplot(111)
 
-        ax.hist(plt.data.flat, histtype='stepfilled',
+        ax.hist(plt.data.ravel(), histtype='stepfilled',
                 bins=freedman_bins(plt.data))
         self.dlg.span = SpanSelector(ax,
                                      lambda x, y : self.change_clim(x, y, plt),
@@ -317,7 +317,7 @@ class DataPlotterManager:
             try:
                 ax = self.dlg.figure.axes[0]
                 ax.cla()
-                ax.hist(img.flat, histtype='stepfilled',
+                ax.hist(img.ravel(), histtype='stepfilled',
                         bins=freedman_bins(img))
                 self.dlg.figure.canvas.draw()
             except:
