@@ -167,7 +167,7 @@ A checked box represents a positive beam and an unchecked box a negative beam.
         return sign
 
     def on_select(self, data, add):
-        st = '%d, %d, %d' % tuple(map(int, data))
+        st = '%d, %d, %d' % (int(data[0]), int(data[1]), int(data[2]) * 2)
         ind = self.search_bbox(st, 1)
         if not add and ind >= 0:
             self.beamBox.DeleteItem(ind)
@@ -336,7 +336,6 @@ class ReflexBaseGui(wx.App):
         if self.needs_resize:
             self.canvas.SetSize(self.plotPanel.GetSize())
             self.needs_resize = False
-        wx.WakeUpIdle()
 
     def onFileInfoPaneChanged(self, event):
         self.filesInfo.GetParent().Layout()
