@@ -1,4 +1,4 @@
-/* $Id: visir_parameter.c,v 1.29 2012/02/02 10:30:05 jtaylor Exp $
+/* $Id: visir_parameter.c,v 1.32 2013-02-27 11:06:35 jtaylor Exp $
  *
  * This file is part of the VISIR Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: jtaylor $
- * $Date: 2012/02/02 10:30:05 $
- * $Revision: 1.29 $
- * $Name: visir-3_5_1 $
+ * $Date: 2013-02-27 11:06:35 $
+ * $Revision: 1.32 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -201,7 +201,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "The file must consist of one line per input FITS-file "
                         "and each line must consist of an integer (which is "
                         "ignored) followed by a 0 or 1 (to indicate object or sky). ",
-                        "", "nod");
+                        VISIR_STR_PAR_EMPTY, "nod");
 
     /* --auto_bpm */
     VISIR_PARAMETER_SET(VISIR_PARAM_AUTOBPM, "auto_bpm", CPL_TYPE_BOOL,
@@ -238,6 +238,12 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "pixel the largest n2 pixel values shall be ignored in "
                         "the averaging.", "0-0", "rej");
 
+    VISIR_PARAMETER_SET(VISIR_PARAM_BKG_CORRECT, "bkgcorrect", CPL_TYPE_BOOL,
+                        "Subtract the median from the spectral column before "
+                        "extracting the wavelength. This is required when "
+                        "the skylines do not correctly cancel due to gratting "
+                        "oscillations", FALSE, "bkgcorrect");
+
     /* --plot */
     VISIR_PARAMETER_SET(VISIR_PARAM_PLOT, "plot", CPL_TYPE_INT,
                         visir_plot_manpage, 0, "plot");
@@ -250,12 +256,13 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
     }
 
 
+    /* TODO temporary aquarius parameters for commissioning, not very good */
     /* --slit_skew */
     /* The detector skew in pixels over the hole detector */
     /* phi = atan(28.6/1024); */
     VISIR_PARAMETER_SET(VISIR_PARAM_SLITSKEW, "phi", CPL_TYPE_DOUBLE,
                         "Distortion correction: Skew of slit (degrees) "
-                        "(clockwise)", zerodist ? 0.0 : 1.6, "slit_skew");
+                        "(clockwise)", zerodist ? 0.0 : 0.52, "slit_skew");
 
     /* --spectrum_skew */
     /* The detector skew in pixels over the hole detector */
@@ -263,7 +270,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
     VISIR_PARAMETER_SET(VISIR_PARAM_SPECSKEW, "ksi", CPL_TYPE_DOUBLE,
                         "Distortion correction: LMR Skew of spectrum (degrees) "
                         "(counter-clockwise). Not used in High Resolution",
-                        zerodist ? 0.0 : 0.7, "spectrum_skew");
+                        zerodist ? 0.0 : 1.73, "spectrum_skew");
 
     /* --vert_arc */
     /* LR eps = 0.052mm/0.050mm  [pixel] (PXSPACE = 50 micron) */
@@ -271,7 +278,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "Distortion correction: LR Detector vertical curvature "
                         "(pixel). Reduced by a factor 4 in MR. Not used in HR "
                         "A-side. Increased by a factor 115/52 in HR B-side",
-                        zerodist ? 0.0 : 1.04, "vert_arc");
+                        zerodist ? 0.0 : -0.8, "vert_arc");
 
     /* --hori_arc */
     /* delta = 0.004mm/0.050mm [pixel] (PXSPACE = 50 micron) */
@@ -279,7 +286,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "Distortion correction: LMR Detector horizontal "
                         "curvature (pixel). Increased by a factor 1.5 in HR "
                         "A-side. Reduced by a factor 2 in HR B-side",
-                        zerodist ? 0.0 : 0.08, "hori_arc");
+                        zerodist ? 0.0 : 0, "hori_arc");
 
     /* --orderoffset */
     VISIR_PARAMETER_SET(VISIR_PARAM_ORDEROFF, "orderoffset", CPL_TYPE_INT,
@@ -305,7 +312,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "offsets mean that the i'th X offset can be gotten "
                         "from Xoffset_0 - Xoffset_i, where Xoffset_i is the "
                         "value of " VISIR_PFITS_DOUBLE_CUMOFFSETX " and "
-                        "likewise for Y.", "", "off");
+                        "likewise for Y.", VISIR_STR_PAR_EMPTY, "off");
 
     VISIR_PARAMETER_SET(VISIR_PARAM_REFINE, "refine", CPL_TYPE_BOOL,
                         "User-defined refining of the image offsets. See "
@@ -320,7 +327,7 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
                         "point with each line consisting of its x and y "
                         "coordinate (in pixels). This file is ignored with "
                         "user-defined refining of offsets disabled.",
-                        "", "objs");
+                        VISIR_STR_PAR_EMPTY, "objs");
 
 
     /* --xcorr */
@@ -378,12 +385,8 @@ cpl_error_code visir_parameter_set(cpl_parameterlist * self,
 
     /* --qeff */
     VISIR_PARAMETER_SET(VISIR_PARAM_QEFF, "qeff", CPL_TYPE_DOUBLE,
-                        "The overall Quantum-efficiency. The default value "
-                        "comes from PH. Galdemard measurements. This option "
-                        "is ignored for all but " VISIR_SPC_QEFF_ASCII
-                        "-tagged files, while the efficiencies in such files "
-                        "are multiplied by this overall efficiency",
-                        0.72, "qeff");
+                        "Ignored",
+                        1.0, "qeff");
 
     /* --r */
     VISIR_PARAMETER_SET(VISIR_PARAM_REJBORD, "rej_bord", CPL_TYPE_STRING,
@@ -520,6 +523,9 @@ cpl_boolean visir_parameterlist_get_bool(const cpl_parameterlist * self,
     /* --mstripe */
     VISIR_PARAMETER_GET_BOOL(VISIR_PARAM_STRIPMOR, "mstripe");
 
+    /* --bkgcorrect */
+    VISIR_PARAMETER_GET_BOOL(VISIR_PARAM_BKG_CORRECT, "bkgcorrect");
+
 
     cpl_ensure(bitmask == 0, CPL_ERROR_UNSUPPORTED_MODE, CPL_FALSE);
     cpl_ensure(nbits == 1,   CPL_ERROR_ILLEGAL_INPUT, CPL_FALSE);
